//  Copyright (c) 2007-2012 Hartmut Kaiser
//
//  SPDX-License-Identifier: BSL-1.0
//  Distributed under the Boost Software License, Version 1.0. (See accompanying
//  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

#pragma once

#include <hpx/config.hpp>

#include <hpx/components/client_base.hpp>
#include <hpx/runtime_configuration/component_factory_base.hpp>
#include <hpx/runtime_distributed/stubs/runtime_support.hpp>
